# As discussed in the Fedora packaging mailing list
# the package is named tor-arm as in Debian to avoid conflicts
# http://lists.fedoraproject.org/pipermail/packaging/2011-October/007945.html
Name:           tor-arm
Version:        1.4.5.0
Release:        10%{?dist}
Summary:        Terminal status monitor for Tor

Group:          Applications/Communications
License:        GPLv3
URL:            http://www.atagar.com/arm/
Source0:        http://www.atagar.com/arm/resources/static/arm-%{version}.tar.bz2
Source1:        http://www.atagar.com/arm/resources/static/arm-%{version}.tar.bz2.asc
# https://trac.torproject.org/projects/tor/ticket/5973
Patch1:         %{name}-1.4.5.0-usrmove.patch
BuildRoot:      %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)

BuildArch:      noarch
BuildRequires:  python2-devel
BuildRequires:  desktop-file-utils
Requires:       pytorctl

%description
The anonymizing relay monitor (arm) is a terminal status monitor for Tor relays,
intended for command-line aficionados, ssh connections, and anyone with a tty
terminal. This works much like top does for system usage, providing real time
statistics for:

 - bandwidth, CPU, and memory usage
 - relay's current configuration
 - logged events
 - connection details (IP, host name, fingerprint, and consensus data)
 - etc.

%package gui
Summary:        GTK frontend for %{name}
Group:          Applications/Communications
Requires:       %{name} = %{version}-%{release}
Requires:       python-cagraph

%description gui
This package provides a GTK based frontend for %{name}

%package devel
Summary:        Development files for tor-arm
Group:          Development/System
Requires:       %{name} = %{version}-%{release}

%description devel
This package contains example code for building a setuid binary to be able to
modify Tor config at run time


%prep
%setup -q -n arm
%patch1 -p1


%build
%{__python} setup.py build


%install
rm -rf %{buildroot}
%{__python} setup.py install --skip-build --root=%{buildroot}
# This lives in pytorctl
rm -rf %{buildroot}%{_datadir}/arm/TorCtl
chmod 0755 %{buildroot}%{_datadir}/arm/starter.py \
           %{buildroot}%{_datadir}/arm/test.py
install -d %{buildroot}%{_datadir}/icons/hicolor/scalable/apps \
           %{buildroot}%{_datadir}/applications
mv %{buildroot}%{_datadir}/arm/resources/%{name}.svg \
     %{buildroot}%{_datadir}/icons/hicolor/scalable/apps
desktop-file-install --dir=%{buildroot}%{_datadir}/applications \
     %{buildroot}%{_datadir}/arm/resources/%{name}.desktop
# Remove unnecessary installed files
rm -rf %{buildroot}%{_docdir}
rm -f %{buildroot}%{_datadir}/arm/uninstall \
      %{buildroot}%{_datadir}/arm/resources/arm.1 \
      %{buildroot}%{_datadir}/arm/resources/torrcOverride/override.c \
      %{buildroot}%{_datadir}/arm/resources/torrcOverride/override.h \
      %{buildroot}%{_datadir}/arm/resources/%{name}.desktop


%clean
rm -rf %{buildroot}


%post gui
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :


%postun gui
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi


%posttrans gui
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :


%files
%defattr(-,root,root,-)
%doc ChangeLog README armrc.sample
%license LICENSE
%{_mandir}/man1/arm.1.*
%{_bindir}/arm
%{_datadir}/arm
%{_datadir}/arm-%{version}*.egg-info

%files gui
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_datadir}/applications/%{name}.desktop

%files devel
%doc src/resources/torrcOverride/override.c src/resources/torrcOverride/override.h


%changelog
* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.5.0-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Thu Apr 09 2015 Juan Orti Alcaine <jorti@fedoraproject.org> - 1.4.5.0-9
- Use license macro

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.5.0-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Tue Apr 15 2014 Juan Orti Alcaine <jorti@fedoraproject.org> - 1.4.5.0-7
- Split the GUI into its own subpackage
- Remove realname variable

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.5.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Feb 26 2013 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.5.0-5
- Update Source URL

* Fri Feb 15 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.5.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.5.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Mon May 28 2012 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.5.0-2
- Fix usrmove bug in wrapper script

* Wed May 2 2012 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.5.0-1
- New upstream version 1.4.5.0
- Drop icon and desktop file because now they are included in the tarball

* Wed Apr 25 2012 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.4.1-12
- Create devel subpackage

* Wed Apr 25 2012 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.4.1-11
- Add wildcard to man page in the files section

* Thu Apr 19 2012 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.4.1-10
- Remove Tor onion from icon due to Tor trademark reasons

* Wed Apr 18 2012 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.4.1-9
- Add icon and desktop file
- Change build and install commands

* Thu Apr 12 2012 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.4.1-8
- Change realname variable to global
- Drop unnecessary python_sitelib definition
- Add example C code to documentation

* Thu Dec 22 2011 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.4.1-7
- Remove python_sitearch definition
- Remove patch

* Tue Dec 13 2011 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.4.1-6
- Change package name of the cagraph dependency

* Tue Oct 11 2011 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.4.1-5
- Package name changed to tor-arm

* Mon Oct 10 2011 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.4.1-4
- Minor fixes

* Sun Oct 09 2011 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.4.1-3
- Require python >= 2.5.0

* Sun Oct 02 2011 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.4.1-2
- Improved compatibility with Suse

* Fri Sep 30 2011 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.4.1-1
- Updated to version 1.4.4.1

* Tue Sep 27 2011 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.4.0-3
- noarch exception for EPEL

* Tue Sep 27 2011 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.4.0-2
- Separate cagraph and TorCtl in different packages

* Fri Sep 23 2011 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.4.0-1
- First edition of the package
